@@ -1,5 +1,6 @@
 import boto3
 import logging
+import time
 
 from botocore.exceptions import ClientError
 from datetime import datetime
@@ -225,7 +226,7 @@ class TimestreamLoader(TimestreamReader):
         self._logger.debug(f"Writing upsert records with {len(records)} records")
         accepted_records, rejected_records = records, []
         try:
-            common_att = {"MeasureValueType": "DOUBLE", "Version": self._current_time_ms}
+            common_att = {"MeasureValueType": "DOUBLE", "Version": int(time.time() * 1000)}
             if is_multi:
                 common_att["MeasureName"] = source or "multi-measure"
                 common_att["MeasureValueType"] = "MULTI"
@@ -376,3 +377,4 @@ class TimestreamLoader(TimestreamReader):
             return [
                 TimestreamRecordMulti(measure_values=records, dimensions=dimensions, mstime=mstime)
             ]
+
